pub struct CreateUserCommandSnippetOptions {
pub user_uuid: Uuid,
pub name: CompactString,
pub eggs: Vec<Uuid>,
pub command: CompactString,
}Fields
user_uuid: Uuidname: CompactStringeggs: Vec<Uuid>command: CompactStringTrait Implementations
Sourceimpl ComposeSchema for CreateUserCommandSnippetOptions
impl ComposeSchema for CreateUserCommandSnippetOptions
Sourceimpl<'de> Deserialize<'de> for CreateUserCommandSnippetOptions
impl<'de> Deserialize<'de> for CreateUserCommandSnippetOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for CreateUserCommandSnippetOptions
impl ToSchema for CreateUserCommandSnippetOptions
Sourceimpl Validate for CreateUserCommandSnippetOptions
impl Validate for CreateUserCommandSnippetOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for CreateUserCommandSnippetOptions
impl RefUnwindSafe for CreateUserCommandSnippetOptions
impl Send for CreateUserCommandSnippetOptions
impl Sync for CreateUserCommandSnippetOptions
impl Unpin for CreateUserCommandSnippetOptions
impl UnwindSafe for CreateUserCommandSnippetOptions