pub struct UpdateUserCommandSnippetOptions {
pub name: Option<CompactString>,
pub eggs: Option<Vec<Uuid>>,
pub command: Option<CompactString>,
}Fields
name: Option<CompactString>eggs: Option<Vec<Uuid>>command: Option<CompactString>Trait Implementations
Sourceimpl ComposeSchema for UpdateUserCommandSnippetOptions
impl ComposeSchema for UpdateUserCommandSnippetOptions
Sourceimpl Default for UpdateUserCommandSnippetOptions
impl Default for UpdateUserCommandSnippetOptions
Sourcefn default() -> UpdateUserCommandSnippetOptions
fn default() -> UpdateUserCommandSnippetOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UpdateUserCommandSnippetOptions
impl<'de> Deserialize<'de> for UpdateUserCommandSnippetOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for UpdateUserCommandSnippetOptions
impl ToSchema for UpdateUserCommandSnippetOptions
Sourceimpl Validate for UpdateUserCommandSnippetOptions
impl Validate for UpdateUserCommandSnippetOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for UpdateUserCommandSnippetOptions
impl RefUnwindSafe for UpdateUserCommandSnippetOptions
impl Send for UpdateUserCommandSnippetOptions
impl Sync for UpdateUserCommandSnippetOptions
impl Unpin for UpdateUserCommandSnippetOptions
impl UnwindSafe for UpdateUserCommandSnippetOptions